==> apache-seata-2.4.0-incubating-src.tar.gz: apache-seata-2.4.0-incubating-src/server/src/main/java/org/apache/seata/server/console/impl/AbstractLockService.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.seata.server.console.impl;

import org.apache.seata.common.util.StringUtils;
import org.apache.seata.common.result.SingleResult;
import org.apache.seata.server.console.entity.param.GlobalLockParam;
import org.apache.seata.server.console.service.GlobalLockService;

public abstract class AbstractLockService extends AbstractService implements GlobalLockService {

    @Override
    public SingleResult<Boolean> check(String xid, String branchId) {
        try {
            commonCheckAndGetGlobalStatus(xid, branchId);
        } catch (IllegalArgumentException e) {
            return SingleResult.success(Boolean.FALSE);
        }
        return SingleResult.success(Boolean.TRUE);
    }

    protected void checkDeleteLock(GlobalLockParam param) {
        commonCheck(param.getXid(), param.getBranchId());
        if (StringUtils.isBlank(param.getTableName()) || StringUtils.isBlank(param.getPk())
                || StringUtils.isBlank(param.getResourceId())) {
            throw new IllegalArgumentException("tableName or resourceId or pk can not be empty");
        }
    }
}

==> apache-seata-2.6.0-incubating-src.tar.gz: apache-seata-2.6.0-incubating-src/server/src/main/java/org/apache/seata/server/console/impl/AbstractLockService.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.seata.server.console.impl;

import org.apache.seata.common.result.SingleResult;
import org.apache.seata.common.util.StringUtils;
import org.apache.seata.server.console.entity.param.GlobalLockParam;
import org.apache.seata.server.console.service.GlobalLockService;

public abstract class AbstractLockService extends AbstractService implements GlobalLockService {

    @Override
    public SingleResult<Boolean> check(String xid, String branchId) {
        try {
            commonCheckAndGetGlobalStatus(xid, branchId);
        } catch (IllegalArgumentException e) {
            return SingleResult.success(Boolean.FALSE);
        }
        return SingleResult.success(Boolean.TRUE);
    }

    protected void checkDeleteLock(GlobalLockParam param) {
        commonCheck(param.getXid(), param.getBranchId());
        if (StringUtils.isBlank(param.getTableName())
                || StringUtils.isBlank(param.getPk())
                || StringUtils.isBlank(param.getResourceId())) {
            throw new IllegalArgumentException("tableName or resourceId or pk can not be empty");
        }
    }
}
